[<img width=250px src=https://www.ilamb.org/assets/images/RUBISCO1.png>](https://www.bgc-feedbacks.org/)

*Experimental version under development*

[![Continuous Integration][ci-badge]][ci-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![Code Coverage Status][codecov-badge]][codecov-link]

# ILAMB - International Land Model Benchmarking

The python package designed to help confront earth system models with reference
data products, and then present the results in a hierarchical set of webpages.
Please see [ilamb.org](https://www.ilamb.org) where we have details about the
datasets we use, the results we catalog, and the methods we employ.

This package is being developed and not currently listed in PyPI or conda-forge. You may install it directly from this repository:

```bash
pip install git+https://github.com/rubisco-sfa/ilamb3
```

The above command will install the latest code from the repository.
We will make *releases* as new methods and functionality are ready, updating the documentation as we develop.
To install a specific version of the code, append it to the URL.
The following will install the released version v2025.5.20:

```bash
pip install git+https://github.com/rubisco-sfa/ilamb3@v2025.5.20
```

Eventually this package will replace the current [ILAMB](https://github.com/rubisco-sfa/ILAMB) package. Consult the [documentation](https://ilamb3.readthedocs.io/) for more information on current status and to see what is functional.

## Funding

This research was performed for the *Reducing Uncertainties in
Biogeochemical Interactions through Synthesis and Computation*
(RUBISCO) Scientific Focus Area, which is sponsored by the Regional
and Global Climate Modeling (RGCM) Program in the Climate and
Environmental Sciences Division (CESD) of the Biological and
Environmental Research (BER) Program in the U.S. Department of Energy
Office of Science.

[ci-badge]: https://github.com/rubisco-sfa/ilamb3/actions/workflows/ci.yml/badge.svg?branch=main
[ci-link]: https://github.com/rubisco-sfa/ilamb3/actions/workflows/ci.yml
[rtd-badge]: https://readthedocs.org/projects/ilamb3/badge/?version=latest
[rtd-link]: https://ilamb3.readthedocs.io/en/latest/?badge=latest
[codecov-badge]: https://img.shields.io/codecov/c/github/rubisco-sfa/ilamb3.svg?logo=codecov
[codecov-link]: https://codecov.io/gh/rubisco-sfa/ilamb3
